@@ -11,11 +11,10 @@ use Icinga\Module\Icingadb\Model\Comment;
 use Icinga\Module\Icingadb\Web\Control\SearchBar\ObjectSuggestions;
 use Icinga\Module\Icingadb\Web\Controller;
 use Icinga\Module\Icingadb\Widget\ItemList\CommentList;
-use Icinga\Module\Icingadb\Widget\ShowMore;
 use Icinga\Module\Icingadb\Web\Control\ViewModeSwitcher;
+use Icinga\Module\Icingadb\Widget\ShowMore;
 use ipl\Web\Control\LimitControl;
 use ipl\Web\Control\SortControl;
-use ipl\Web\Filter\QueryString;
 use ipl\Web\Url;
 
 class CommentsController extends Controller
@@ -36,8 +35,6 @@ class CommentsController extends Controller
             'service.state'
         ]);
 
-        $this->handleSearchRequest($comments);
-
         $limitControl = $this->createLimitControl();
         $paginationControl = $this->createPaginationControl($comments);
         $sortControl = $this->createSortControl(
@@ -163,7 +160,7 @@ class CommentsController extends Controller
 
         $this->addControl(new ShowMore(
             $rs,
-            Links::comments()->setQueryString(QueryString::render($this->getFilter())),
+            Links::comments()->setFilter($this->getFilter()),
             sprintf(t('Show all %d comments'), $comments->count())
         ));
 
@@ -172,7 +169,7 @@ class CommentsController extends Controller
                 ->setObjects($comments)
                 ->setAction(
                     Links::commentsDelete()
-                        ->setQueryString(QueryString::render($this->getFilter()))
+                        ->setFilter($this->getFilter())
                         ->getAbsoluteUrl()
                 )
         );
