@@ -11,11 +11,10 @@ use Icinga\Module\Icingadb\Model\Downtime;
 use Icinga\Module\Icingadb\Web\Control\SearchBar\ObjectSuggestions;
 use Icinga\Module\Icingadb\Web\Controller;
 use Icinga\Module\Icingadb\Widget\ItemList\DowntimeList;
-use Icinga\Module\Icingadb\Widget\ShowMore;
 use Icinga\Module\Icingadb\Web\Control\ViewModeSwitcher;
+use Icinga\Module\Icingadb\Widget\ShowMore;
 use ipl\Web\Control\LimitControl;
 use ipl\Web\Control\SortControl;
-use ipl\Web\Filter\QueryString;
 use ipl\Web\Url;
 
 class DowntimesController extends Controller
@@ -36,8 +35,6 @@ class DowntimesController extends Controller
             'service.state'
         ]);
 
-        $this->handleSearchRequest($downtimes);
-
         $limitControl = $this->createLimitControl();
         $paginationControl = $this->createPaginationControl($downtimes);
         $sortControl = $this->createSortControl(
@@ -169,7 +166,7 @@ class DowntimesController extends Controller
 
         $this->addControl(new ShowMore(
             $rs,
-            Links::downtimes()->setQueryString(QueryString::render($this->getFilter())),
+            Links::downtimes()->setFilter($this->getFilter()),
             sprintf(t('Show all %d downtimes'), $downtimes->count())
         ));
 
@@ -178,7 +175,7 @@ class DowntimesController extends Controller
                 ->setObjects($downtimes)
                 ->setAction(
                     Links::downtimesDelete()
-                        ->setQueryString(QueryString::render($this->getFilter()))
+                        ->setFilter($this->getFilter())
                         ->getAbsoluteUrl()
                 )
         );
