@@ -18,13 +18,12 @@ use Icinga\Module\Icingadb\Widget\Detail\ObjectsDetail;
 use Icinga\Module\Icingadb\Widget\ItemList\HostList;
 use Icinga\Module\Icingadb\Widget\HostStatusBar;
 use Icinga\Module\Icingadb\Widget\ItemTable\HostItemTable;
-use Icinga\Module\Icingadb\Widget\ShowMore;
 use Icinga\Module\Icingadb\Web\Control\ViewModeSwitcher;
+use Icinga\Module\Icingadb\Widget\ShowMore;
 use ipl\Orm\Query;
 use ipl\Stdlib\Filter;
 use ipl\Web\Control\LimitControl;
 use ipl\Web\Control\SortControl;
-use ipl\Web\Filter\QueryString;
 use ipl\Web\Url;
 
 class HostsController extends Controller
@@ -42,7 +41,7 @@ class HostsController extends Controller
         $hosts->getWith()['host.state']->setJoinType('INNER');
         $hosts->setResultSetClass(VolatileStateResults::class);
 
-        $this->handleSearchRequest($hosts);
+        $this->handleSearchRequest($hosts, ['address', 'address6']);
 
         $summary = null;
         if (! $compact) {
@@ -54,10 +53,10 @@ class HostsController extends Controller
         $sortControl = $this->createSortControl(
             $hosts,
             [
-                'host.display_name'                 => t('Name'),
-                'host.state.severity desc'          => t('Severity'),
-                'host.state.soft_state'             => t('Current State'),
-                'host.state.last_state_change desc' => t('Last State Change')
+                'host.display_name'                                          => t('Name'),
+                'host.state.severity desc,host.state.last_state_change desc' => t('Severity'),
+                'host.state.soft_state'                                      => t('Current State'),
+                'host.state.last_state_change desc'                          => t('Last State Change')
             ]
         );
         $viewModeSwitcher = $this->createViewModeSwitcher($paginationControl, $limitControl);
@@ -85,7 +84,7 @@ class HostsController extends Controller
         $hosts->peekAhead($compact);
 
         $this->filter($hosts, $filter);
-        if (isset($summary)) {
+        if (! $compact) {
             $this->filter($summary, $filter);
             yield $this->export($hosts, $summary);
         } else {
@@ -121,7 +120,9 @@ class HostsController extends Controller
                     ))
             );
         } else {
-            $this->addFooter((new HostStatusBar($summary->first()))->setBaseFilter($filter));
+            /** @var HoststateSummary $hostsSummary */
+            $hostsSummary = $summary->first();
+            $this->addFooter((new HostStatusBar($hostsSummary))->setBaseFilter($filter));
         }
 
         if (! $searchBar->hasBeenSubmitted() && $searchBar->hasBeenSent()) {
@@ -167,10 +168,11 @@ class HostsController extends Controller
         $this->addControl(
             (new HostList($results))
                 ->setViewMode('minimal')
+                ->setDetailActionsDisabled()
         );
         $this->addControl(new ShowMore(
             $results,
-            Links::hosts()->setQueryString(QueryString::render($this->getFilter())),
+            Links::hosts()->setFilter($this->getFilter()),
             sprintf(t('Show all %d hosts'), $hosts->count())
         ));
         $this->addControl(
@@ -227,7 +229,7 @@ class HostsController extends Controller
 
     protected function getCommandTargetsUrl(): Url
     {
-        return Links::hostsDetails()->setQueryString(QueryString::render($this->getFilter()));
+        return Links::hostsDetails()->setFilter($this->getFilter());
     }
 
     protected function getFeatureStatus()
