@@ -144,6 +144,7 @@ class RedisConfigForm extends ConfigForm
             'description'    => t('Redis Password'),
             'label'          => t('Redis Password'),
             'renderPassword' => true,
+            'autocomplete'   => 'new-password'
         ]);
 
         $this->addDisplayGroup(
@@ -182,6 +183,7 @@ class RedisConfigForm extends ConfigForm
             'description'    => t('Redis Password'),
             'label'          => t('Redis Password'),
             'renderPassword' => true,
+            'autocomplete'   => 'new-password'
         ]);
 
         $this->addDisplayGroup(
@@ -355,6 +357,7 @@ class RedisConfigForm extends ConfigForm
         ));
 
         $useTls = $this->getElement('redis_tls')->isChecked();
+        $pem = null;
         foreach (['ca', 'cert', 'key'] as $name) {
             $textarea = $this->getElement('redis_' . $name . '_pem');
             if ($useTls && $textarea !== null && ($pem = $textarea->getValue())) {
