@@ -234,9 +234,14 @@ class UrlMigrator
                     case $exprRule === self::LOWER_EXPR:
                         $filter->setValue(strtolower($filter->getValue()));
                         break;
-                    case is_array($exprRule) && isset($exprRule[$filter->getValue()]):
-                        $filter->setValue($exprRule[$filter->getValue()]);
-                        break;
+                    case is_array($exprRule):
+                        if (isset($exprRule[$filter->getValue()])) {
+                            $filter->setValue($exprRule[$filter->getValue()]);
+
+                            break;
+                        }
+
+                        return false;
                     default:
                         $filter->setValue($exprRule);
                 }
@@ -290,6 +295,8 @@ class UrlMigrator
             },
             'dir' => self::DROP,
             'limit' => self::USE_EXPR,
+            'addFilter' => self::DROP,
+            'modifyFilter' => self::DROP,
             'showCompact' => self::USE_EXPR,
             'showFullscreen' => self::USE_EXPR,
             'view' => function ($value) {
