@@ -10,6 +10,11 @@ use ipl\Orm\Behaviors;
 use ipl\Orm\Model;
 use ipl\Orm\Relations;
 
+/**
+ * @property string $id
+ * @property string[] $action_url
+ * @property string $environment_id
+ */
 class ActionUrl extends Model
 {
     public function getTableName()
@@ -34,7 +39,7 @@ class ActionUrl extends Model
     {
         return [
             'action_url'        => t('Action Url'),
-            'environment_id'    => t('Action Url Environment Id')
+            'environment_id'    => t('Environment Id')
         ];
     }
 
