@@ -61,27 +61,19 @@ class HostState extends State
     {
         $relations->belongsTo('environment', Environment::class);
         $relations->belongsTo('host', Host::class);
-        $relations->hasOne('last_comment', Comment::class)
+        $relations->hasOne('last_comment', LastHostComment::class)
             ->setCandidateKey('last_comment_id')
             ->setForeignKey('id')
             ->setJoinType('LEFT');
     }
 
-    /**
-     * Get the host state as the textual representation
-     *
-     * @return string
-     */
+
     public function getStateText(): string
     {
         return HostStates::text($this->soft_state);
     }
 
-    /**
-     * Get the host state as the translated textual representation
-     *
-     * @return string
-     */
+
     public function getStateTextTranslated(): string
     {
         return HostStates::text($this->soft_state);
