@@ -10,14 +10,14 @@ use Icinga\Module\Icingadb\Common\Auth;
 use Icinga\Module\Icingadb\Common\Database;
 use Icinga\Module\Icingadb\Common\HostLink;
 use Icinga\Module\Icingadb\Common\Links;
-use Icinga\Module\Icingadb\Widget\EmptyState;
 use Icinga\Module\Icingadb\Widget\MarkdownText;
 use Icinga\Module\Icingadb\Common\ServiceLink;
 use Icinga\Module\Icingadb\Forms\Command\Object\DeleteDowntimeForm;
 use Icinga\Module\Icingadb\Model\Downtime;
 use Icinga\Module\Icingadb\Widget\ItemList\DowntimeList;
-use ipl\Web\Widget\HorizontalKeyValue;
 use Icinga\Module\Icingadb\Widget\ShowMore;
+use ipl\Web\Widget\EmptyState;
+use ipl\Web\Widget\HorizontalKeyValue;
 use ipl\Html\BaseHtmlElement;
 use ipl\Html\Html;
 use ipl\Html\HtmlElement;
@@ -54,7 +54,7 @@ class DowntimeDetail extends BaseHtmlElement
     protected function createCancelDowntimeForm()
     {
         $action = Links::downtimesDelete();
-        $action->setQueryString(QueryString::render(Filter::equal('name', $this->downtime->name)));
+        $action->setFilter(Filter::equal('name', $this->downtime->name));
 
         return (new DeleteDowntimeForm())
             ->setObjects([$this->downtime])
@@ -130,36 +130,36 @@ class DowntimeDetail extends BaseHtmlElement
 
         $this->add(new HorizontalKeyValue(
             t('Created'),
-            WebDateFormatter::formatDateTime($this->downtime->entry_time)
+            WebDateFormatter::formatDateTime($this->downtime->entry_time->getTimestamp())
         ));
         $this->add(new HorizontalKeyValue(
             t('Start time'),
             $this->downtime->start_time
-                ? WebDateFormatter::formatDateTime($this->downtime->start_time)
+                ? WebDateFormatter::formatDateTime($this->downtime->start_time->getTimestamp())
                 : new EmptyState(t('Not started yet'))
         ));
         $this->add(new HorizontalKeyValue(
             t('End time'),
             $this->downtime->end_time
-                ? WebDateFormatter::formatDateTime($this->downtime->end_time)
+                ? WebDateFormatter::formatDateTime($this->downtime->end_time->getTimestamp())
                 : new EmptyState(t('Not started yet'))
         ));
         $this->add(new HorizontalKeyValue(
             t('Scheduled Start'),
-            WebDateFormatter::formatDateTime($this->downtime->scheduled_start_time)
+            WebDateFormatter::formatDateTime($this->downtime->scheduled_start_time->getTimestamp())
         ));
         $this->add(new HorizontalKeyValue(
             t('Scheduled End'),
-            WebDateFormatter::formatDateTime($this->downtime->scheduled_end_time)
+            WebDateFormatter::formatDateTime($this->downtime->scheduled_end_time->getTimestamp())
         ));
         $this->add(new HorizontalKeyValue(
             t('Scheduled Duration'),
-            DateFormatter::formatDuration($this->downtime->scheduled_duration)
+            DateFormatter::formatDuration($this->downtime->scheduled_duration / 1000)
         ));
         if ($this->downtime->is_flexible) {
             $this->add(new HorizontalKeyValue(
                 t('Flexible Duration'),
-                DateFormatter::formatDuration($this->downtime->flexible_duration)
+                DateFormatter::formatDuration($this->downtime->flexible_duration / 1000)
             ));
         }
 
