@@ -50,7 +50,9 @@ class ServiceDetailHeader extends ServiceListItemMinimal
         }
 
         $stateChange->setIcon($this->state->getIcon());
-        $stateChange->setHandled($this->state->is_handled || ! $this->state->is_reachable);
+        $stateChange->setHandled(
+            $this->state->is_problem && ($this->state->is_handled || ! $this->state->is_reachable)
+        );
 
         $visual->addHtml($stateChange);
     }
